import redis from 'redis';
import redisMock, { RedisClient } from 'redis-mock';
import { getRedisInstance } from '../redisManager';

describe('getRedisInstance', () => {
    describe('when no error', () => {
        beforeAll(() => {
            jest.spyOn(redis, 'createClient').mockImplementation(redisMock.createClient);
        });
        afterAll(async() => {
            jest.clearAllMocks();
        });
        test('should create redis instance', () => {
            const redisInstance = getRedisInstance();
            expect(redisInstance).toBeDefined();
            expect(redisInstance).toBeInstanceOf(RedisClient);
        });
    });

    describe('when error', () => {
        beforeAll(() => {
            jest.spyOn(redis, 'createClient').mockImplementation(() => {
                throw new Error();
            });
        });
        afterAll(async() => {
            jest.clearAllMocks();
        });
        test('should create redis instance', () => {
            expect(getRedisInstance).toThrowError();
        });
    });
});
