import { mock } from 'jest-mock-extended';
import {
    ConnectionManager, Repository, SelectQueryBuilder, EntityManager, UpdateQueryBuilder,
    InsertQueryBuilder,
} from 'typeorm';

const mockedRepository = mock<Repository<any>>();
const mockedQueryBuilder = mock<SelectQueryBuilder<any>>();
const mockedInsertQueryBuilder = mock<InsertQueryBuilder<any>>();
const mockedUpdateQueryBuilder = mock<UpdateQueryBuilder<any>>();
const mockedConnectionManager = mock<ConnectionManager>();
const mockEntityManager = mock<EntityManager>();

const connectionObj: any = {
    isConnected: true,
    namingStrategy: {},
    createQueryBuilder: () => mockedQueryBuilder,
    getRepository: () => mockedRepository,
    manager: mockEntityManager,
};

jest.mock('typeorm', () => {
    mockedQueryBuilder.andWhere.mockReturnThis();
    mockedQueryBuilder.cache.mockReturnThis();
    mockedQueryBuilder.leftJoin.mockReturnThis();
    mockedQueryBuilder.where.mockReturnThis();
    mockedQueryBuilder.orWhere.mockReturnThis();
    mockedQueryBuilder.select.mockReturnThis();
    mockedQueryBuilder.addSelect.mockReturnThis();
    mockedQueryBuilder.distinct.mockReturnThis();
    mockedQueryBuilder.distinctOn.mockReturnThis();
    mockedQueryBuilder.from.mockReturnThis();
    mockedQueryBuilder.subQuery.mockReturnThis();
    mockedQueryBuilder.setParameter.mockReturnThis();

    mockedQueryBuilder.update.mockReturnValue(mockedUpdateQueryBuilder);
    mockedUpdateQueryBuilder.set.mockReturnThis();
    mockedUpdateQueryBuilder.where.mockReturnThis();
    mockedUpdateQueryBuilder.execute.mockResolvedValue({
        affected: 1,
        generatedMaps: [],
        raw: { },
    });

    mockedQueryBuilder.leftJoinAndMapOne.mockReturnThis();
    mockedQueryBuilder.leftJoinAndMapMany.mockReturnThis();
    mockedQueryBuilder.leftJoin.mockReturnThis();
    mockedQueryBuilder.andWhere.mockReturnThis();
    mockedQueryBuilder.orderBy.mockReturnThis();
    mockedQueryBuilder.getQuery.mockReturnValue('');

    mockedQueryBuilder.innerJoin.mockReturnThis();

    mockedQueryBuilder.delete.mockReturnThis();

    mockedQueryBuilder.insert.mockReturnValue(mockedInsertQueryBuilder);
    mockedInsertQueryBuilder.into.mockReturnThis();
    mockedInsertQueryBuilder.values.mockReturnThis();

    mockedRepository.createQueryBuilder.mockReturnValue(mockedQueryBuilder);
    mockEntityManager.createQueryBuilder.mockReturnValue(mockedQueryBuilder);
    mockEntityManager.getRepository.mockReturnValue(mockedRepository);
    mockedConnectionManager.has.mockReturnValue(false);
    mockedConnectionManager.get.mockReturnValue(connectionObj);

    return {
        Brackets: class Mock {},
        DefaultNamingStrategy: class Mock {},
        BaseEntity: class Mock {},
        Column: () => {},
        CreateDateColumn: () => {},
        Entity: () => {},
        createConnection: () => Promise.resolve(connectionObj),
        createQueryBuilder: () => mockedQueryBuilder,
        getManager: () => mockEntityManager,
        getConnectionManager: () => mockedConnectionManager,
        getRepository: () => mockedRepository,
        Index: () => {},
        JoinColumn: () => {},
        ManyToOne: () => {},
        OneToMany: () => {},
        PrimaryColumn: () => {},
        PrimaryGeneratedColumn: () => {},
        Unique: () => {},
        OneToOne: () => {},
        ManyToMany: () => {},
        JoinTable: () => {},
        Generated: () => {},
        ViewColumn: () => {},
        ViewEntity: () => {},
    };
});

export {
    mockedConnectionManager,
    mockEntityManager,
    mockedQueryBuilder,
    mockedRepository,
    mockedUpdateQueryBuilder,
    connectionObj,
};
