import express from 'express';
import helmet from 'helmet';
import { Routes } from './routes/Routes';
import morganJson from 'morgan-json';
import swaggerUiExpress from 'swagger-ui-express';
import swaggerJson from './swagger/swagger.json';
import morgan from 'morgan';
import { routeNotFound, criticalPrefix } from './json/en.json';
import { LogErrorCodes } from './utils/ErrorCodes';
import { logError } from './utils/ErrorLogger';
import HealthRouter from './routes/HealthRouter';

class App {
    public app: express.Application;
    public routePrv: Routes;

    constructor() {
        this.app = express();
        this.app.use(helmet());
        this.app.use(express.json({ limit: '500mb' }));
        this.app.use(express.urlencoded({ extended: false }));
        const morganLogFormat = morganJson(':remote-addr :remote-user :date[clf] :method :url :status :res[content-length] - :response-time ms ');
        this.app.use(morgan(morganLogFormat));
        this.app.use(HealthRouter);
        this.routePrv = new Routes();
        this.routePrv.routes(this.app);
        this.app.use('/itemengine-player/api-docs', swaggerUiExpress.serve, swaggerUiExpress.setup(swaggerJson));
        this.app.use((request, response) => {
            logError(LogErrorCodes.REQUEST_NOT_FOUND, `${criticalPrefix} ${request.url}: ${routeNotFound}`);
            return response.status(LogErrorCodes.REQUEST_NOT_FOUND)
            .send({ message: `${request.url}: ${routeNotFound}` });
        });
    }
}

export default new App().app;
