import {
    Column,
    PrimaryGeneratedColumn,
    Index,
} from 'typeorm';

export abstract class AssignmentStudentMappingEntity {
    @PrimaryGeneratedColumn()
    public id: number;

    @Index('assignmentstudentmapping_assignment_id_idx')
    @Column({
        name: 'assignment_id',
    })
    public assignmentId: number;

    @Index('assignmentstudentmapping_student_id_idx')
    @Column('uuid', {
        name: 'student_id',
        nullable: true,
    })
    public studentId: string;

    @Column({
        name: 'started_at',
        nullable: true,
    })
    public startedAt: Date;

    @Column({
        name: 'ended_at',
        nullable: true,
    })
    public endedAt: Date;

    @Column({
        name: 'points_scored',
        nullable: true,
        type: 'real',
    })
    public pointsScored: number;

    @Index('assignmentstudentmapping_graded_idx')
    @Column({
        default: false,
    })
    public graded: boolean;

    @Index('assignmentstudentmapping_teacher_status_idx')
    @Column({
        name: 'teacher_status_id',
        nullable: true,
    })
    public teacherStatusId: number;

    @Index('assignmentstudentmapping_student_status_idx')
    @Column({
        name: 'student_status_id',
        nullable: true,
    })
    public studentStatusId: number;

    @Column({
        name: 'updated_at',
        type: 'timestamp without time zone',
        nullable: true,
        default: () => 'now()',
    })
    public updatedAt: Date;

    @Index('assignmentstudentmapping_percentage_idx')
    @Column({
        name: 'percentage',
        nullable: true,
        type: 'real',
    })
    public percentage: number;

    @Index('assignmentstudentmapping_grading_status_id_idx')
    @Column({
        name: 'grading_status_id',
        nullable: true,
        default: 2,
    })
    public gradingStatusId: number;

    @Index('assignmentstudentmapping_is_assignment_launched_idx')
    @Column({
        name: 'is_assignment_launched',
        nullable: true,
        default: false,
    })
    public isAssignmentLaunched: boolean;

    @Index('assignmentstudentmapping_created_at_idx')
    @Column({
        type: 'timestamp',
        name: 'created_at',
        nullable: true,
    })
    public createdAt: Date;
}

export default AssignmentStudentMappingEntity;
