import {
    Column,
    PrimaryGeneratedColumn,
    Index,
    Generated,
} from 'typeorm';

export abstract class AssignmentsEntity {
    @PrimaryGeneratedColumn()
    public id: number;

    @Index('assignments_assignment_id_idx')
    @Generated('uuid')
    @Column('uuid', {
        name: 'assignment_id',
    })
    public assignmentId: string;

    @Index('assignments_open_date_idx')
    @Column({
        type: 'timestamp without time zone',
        name: 'open_date',
        nullable: true,
        precision: 0,
    })
    public openDate: Date;

    @Index('assignments_due_date_idx')
    @Column({
        type: 'timestamp without time zone',
        name: 'due_date',
        nullable: true,
        precision: 0,
    })
    public dueDate: Date;

    @Index('assignments_assessment_id_idx')
    @Column('uuid', {
        name: 'assessment_id',
    })
    public assessmentId: string;

    @Index('assignments_created_at_idx')
    @Column({
        type: 'timestamp',
        name: 'created_at',
        nullable: true,
        default: () => 'now()',
        precision: 0,
    })
    public createdAt: Date;

    @Column({
        name: 'updated_at',
        type: 'timestamp without time zone',
        nullable: true,
        default: () => 'now()',
    })
    public updatedAt: Date;

    @Index('assignments_created_by_idx')
    @Column('uuid', {
        name: 'created_by',
        nullable: true,
    })
    public createdBy: string;

    @Index('assignments_is_manually_open_idx')
    @Column({
        name: 'is_manually_open',
        nullable: true,
    })
    public isManuallyOpen: boolean;

    @Index('assignments_is_manually_close_idx')
    @Column({
        name: 'is_manually_close',
        nullable: true,
    })
    public isManuallyClose: boolean;

    @Index('assignments_stage_id_idx')
    @Column({
        name: 'assignment_stage_id',
        nullable: true,
        default: 1,
    })
    public assignmentStageId: number;

    @Column({
        name: 'is_close_now',
        nullable: true,
        default: false,
    })
    public isCloseNow: boolean;

    @Column({
        name: 'is_open_now',
        nullable: true,
        default: false,
    })
    public isOpenNow: boolean;

    @Index('assignments_close_on_idx')
    @Column({
        name: 'close_on',
        type: 'timestamp without time zone',
        nullable: true,
    })
    public closeOn: Date;

    @Column({
        name: 'closed_on_date',
        type: 'timestamp without time zone',
        nullable: true,
    })
    public closedOnDate: Date;

    @Index('assignments_launched_at_idx')
    @Column({
        type: 'timestamp',
        name: 'launched_at',
        nullable: true,
        default: () => 'now()',
        precision: 0,
    })
    public launchedAt: Date;
}

export default AssignmentsEntity;
