import { createConnection, ConnectionOptions, getConnectionManager } from 'typeorm';
import 'dotenv/config';
import { SnakeNamingStrategy } from 'typeorm-naming-strategies';
import ConnectionTest from '../models/ConnectionTest';
import { getTypeormCacheOptions } from '../utils/typeormCache';
import { getTypeormExtraOptions } from '../utils/typeormExtra';
import Assignments from '../models/Assignments';
import AssignmentStage from '../models/AssignmentStage';
import TeacherStatus from '../models/TeacherStatus';
import StudentStatus from '../models/StudentStatus';
import AssignmentStudentMapping from '../models/AssignmentStudentMapping';
import Response from '../models/Response';
import GradingStatus from '../models/GradingStatus';
import AssignmentsQuestionMap from '../models/AssignmentsQuestionMap';
import QuestionQuestionpartMap from '../models/QuestionQuestionpartMap';

const connectionName = 'assignmentConnection';
const connectionManager = getConnectionManager();
let connection;

const config: ConnectionOptions = {
    name: connectionName,
    type: 'postgres',
    host: process.env.POSTGRESCONNECTION__HOST,
    port: Number(process.env.POSTGRESCONNECTION__PORT),
    username: process.env.POSTGRESCONNECTION__USERNAME,
    password: process.env.POSTGRESCONNECTION__PASSWORD,
    database: process.env.PLAYER__DATABASE_NAME,
    schema: process.env.PLAYER__DATABASE_SCHEMA_NAME,
    entities: [
        ConnectionTest, Assignments, AssignmentStage, TeacherStatus, StudentStatus,
        AssignmentStudentMapping, Response, GradingStatus,
        AssignmentsQuestionMap, QuestionQuestionpartMap,
    ],
    synchronize: (process.env.PLAYER__TYPEORM_SYNCHRONIZE === 'true' ? true : false),
    logging: (process.env.PLAYER__TYPEORM_LOGGING === 'true' ? true : false),
    namingStrategy: new SnakeNamingStrategy(),
    maxQueryExecutionTime: 300,
    cache: getTypeormCacheOptions(),
    extra: getTypeormExtraOptions(),
};

if (connectionManager.has(connectionName)) {
    console.info('using existing connection ...');
    connection = connectionManager.get(connectionName);

    if (!connection.isConnected) {
        connection = connection.connect();
    }
} else {
    console.info('creating connection ...');
    connection = createConnection(config);
}

export {
    connection,
};
