import {
    Entity,
    ManyToOne,
    JoinColumn,
    OneToMany,
    Index,
    Column,
} from 'typeorm';
import { TableNames } from '../utils/TableNames';
import { TeacherStatus } from './TeacherStatus';
import { StudentStatus } from './StudentStatus';
import { Assignments } from './Assignments';
import { GradingStatus } from './GradingStatus';
import { AssignmentsQuestionMap } from './AssignmentsQuestionMap';
import { AssignmentStudentMappingEntity } from '../baseModels/AssignmentStudentMappingEntity';

@Entity({ name: TableNames.ASSIGNMENTSTUDENTMAPPING })
export class AssignmentStudentMapping extends AssignmentStudentMappingEntity {

    @Index('student_session_id_idx')
    @Column({
        name: 'session_id',
        nullable: false,
    })
    public sessionId: String;

    @ManyToOne(
        (type) => TeacherStatus,
        (teacherStatus) => teacherStatus.singleAssignment
    )
    @JoinColumn({ name: 'teacher_status_id', referencedColumnName: 'id' })
    teacherStatus: TeacherStatus;

    @ManyToOne(
        (type) => StudentStatus,
        (studentStatus) => studentStatus.singleAssignment
    )
    @JoinColumn({ name: 'student_status_id', referencedColumnName: 'id' })
    studentStatus: StudentStatus;

    @ManyToOne((type) => Assignments, (assignedClass) => assignedClass.students)
    @JoinColumn({ name: 'assignment_id', referencedColumnName: 'id' })
    assignments: Assignments[];

    @ManyToOne(
        (type) => GradingStatus,
        (gradingStatus) => gradingStatus.assignedStudents
    )
    @JoinColumn({ name: 'grading_status_id', referencedColumnName: 'id' })
    gradingStatus: GradingStatus;

    @OneToMany(
        (type) => AssignmentsQuestionMap,
        (assignmentQuestionMap) => assignmentQuestionMap.studentAssignment,
        { cascade: true }
    )
    @JoinColumn({ name: 'id', referencedColumnName: 'student_assignment_id' })
    questions: AssignmentsQuestionMap[];
}

export default AssignmentStudentMapping;
