import {
    Entity,
    ManyToOne,
    JoinColumn,
    OneToMany,
    Unique,
    Index,
    Column,
} from 'typeorm';
import { TableNames } from '../utils/TableNames';
import { AssignmentStudentMapping } from './AssignmentStudentMapping';
import { AssignmentStage } from './AssignmentStage';
import { AssignmentsEntity } from '../baseModels/AssignmentsEntity';

@Unique('unique_assignment_id_constraint', ['assignmentId'])
@Entity({ name: TableNames.ASSIGNMENTS })
export class Assignments extends AssignmentsEntity {

    @Index('assignments_reference_id_idx')
    @Column({
        name: 'reference_id',
        nullable: false,
    })
    public referenceId: String;

    @Index('assignment_organisation_id_idx')
    @Column({
        name: 'organisation_id',
        nullable: false,
        type: 'uuid',
    })
    public organisationId: string;

    @ManyToOne((type) => AssignmentStage, (stage) => stage.assignments)
    @JoinColumn({ name: 'assignment_stage_id', referencedColumnName: 'id' })
    assignmentStage: AssignmentStage;

    @OneToMany(
        (type) => AssignmentStudentMapping,
        (students) => students.assignments
    )
    @JoinColumn({ name: 'id', referencedColumnName: 'assignment_id' })
    students: AssignmentStudentMapping[];
}

export default Assignments;
