import debug from 'debug';
import redis, { RedisClient } from 'redis';
import getEnv from './utils/getEnv';

const getStringEnv = (key: string): string => {
    const value = getEnv(key, '');
    if (value === null) {
        throw new Error(`${key} cannot be null`);
    }
    return value.toString();
};

const getNumberEnv = (key: string): number => {
    const value = getEnv(key, '');
    if (value === null) {
        throw new Error(`${key} cannot be null`);
    }
    return Number(value);
};

const getRedisInstance = () => {
    try {
        const logger = debug('redis-handler');
        logger.enabled = true;

        const redisConfig: redis.ClientOpts = {
            host: getStringEnv('REDIS__HOST'),
            port: getNumberEnv('REDIS__PORT'),
            db: getStringEnv('REDIS__DATABASE'),
        };
        if (getEnv('REDIS__ENABLE_PASSWORD', false)) redisConfig.password = getStringEnv('REDIS__PASSWORD');
        if (getEnv('REDIS__ENABLE_SSL', false)) redisConfig.tls = {};

        const redisInstance: RedisClient = redis.createClient(redisConfig);
        return redisInstance;
    } catch (error) {
        throw(new Error('Redis disabled.'));
    }
};

export {
    getRedisInstance,
};
