import express from 'express';
import { connection } from '../config/ormconfig';
import { LogErrorCodes } from '../utils/ErrorCodes';
import { logError, logInfo  } from '../utils/ErrorLogger';
import { dbConSuccess, criticalPrefix, logPrefix } from '../json/en.json';
import ConnectionTest from '../models/ConnectionTest';
import  { isNullOrUndefined } from '../utils/Validators';

const healthRouter = express.Router();

healthRouter.route('/healthcheck2').get(async(request, response) => {
    const dbConfigs = connection;
    const dbCheckResult = await checkDBHealth(dbConfigs);
    if (!isNullOrUndefined(dbCheckResult) && dbCheckResult.check) {
        response.status(200).send({
            status: 'Available',
        });
    } else {
        response.status(500).send({
            status: 'Unavailable',
            error_code: 501,
            error: dbCheckResult.statusText,
        });
    }
});

healthRouter.route('/healthcheck').get(async(request, response) => {
    response.status(200).send({
        status: 'Available',
        name: 'itemengine-player-api-service',
    });
});

healthRouter.route('/internal-healthcheck').get(async(request, response) => {
    response.status(200).send({
        status: 'Available',
    });
});

const checkDBHealth = async (configurations: any) => {
    return configurations
            .then(async (conn) => {
                const query = conn.createQueryBuilder(ConnectionTest, 'connection_test');
                await query.getOne();
                logInfo(LogErrorCodes.DB_CONNECT_SUCCESS, `${logPrefix} ${dbConSuccess}...`);
                return { check: true, status: 200, statusText: 'OK' };
            })
            .catch((error) => {
                logError(LogErrorCodes.DB_CONNECT_ERROR, `${criticalPrefix} ${error}`);
                return { check: false, status: 501, statusText: error };
            });
};

export default healthRouter;
