import 'dotenv/config';
import app from './app';
import { listening, secured_listening } from './json/en.json';
import https from 'https';
import fs from 'fs';
import logger from './utils/logger';

const port = process.env.PORT;
const isSSL = process.env.IS_SSL;
const keyPath = process.env.SSL_KEY_PATH;
const certPath = process.env.SSL_CERTIFICATE_PATH;
const keepAliveTimeout = process.env.PLAYER__KEEP_ALIVE_TIMEOUT || 65000;

try {
    let server;
    if (isSSL === 'true' && fs.existsSync(keyPath) && fs.existsSync(certPath)) {
        const options = {
            key: fs.readFileSync(keyPath),
            cert: fs.readFileSync(certPath),
            requestCert: false,
            rejectUnauthorized: false,
        };
        server = https.createServer(options, app).listen(port, () => {
            logger.info(`${secured_listening} ${port}`);
        });
    } else {
        server = app.listen(port, () => {
            logger.info(`${listening} ${port}`);
        });
    }
    server.keepAliveTimeout = Number(keepAliveTimeout);
} catch (err) {
    logger.error(err);
}
