export enum LogErrorCodes {
    UNAUTHORIZED_USER = 401, // Unauthorized access
    INVALID_REQUEST = 422, // Invalid Request
    RESPONSE_ERROR = 500,  // Error while getting response
    DB_CONNECT_SUCCESS = 200, // Database connected successfully
    DB_CONNECT_ERROR = 501, // Cannot connect to database
    REQUEST_NOT_FOUND = 404, // Request Not Found
}

export const serverErrorCodes = {
    UNAUTHORIZED_USER:
        { statusCode: 401, errorCode: 401, message: 'Invalid user' },
    UNAUTHORIZED_STUDENT_USER:
        { statusCode: 401, errorCode: 401, message: 'Invalid student user' },
    UNAUTHORIZED_TEACHER_USER:
        { statusCode: 401, errorCode: 401, message: 'Invalid teacher user' },
    INVALID_REQUEST:
        { statusCode: 422, errorCode: 422, message: 'Invalid Assignment id' },
    NO_ASSIGNMENT:
        { statusCode: 500, errorCode: 1500, message: 'Assignment does not exist' },
    NO_ACCESS:
        { statusCode: 500, errorCode: 1501, message: 'Student does not have access to this Assignment' },
    CLASS_MISMATCH:
        { statusCode: 500, errorCode: 1502, message: 'Student class does not match Assignment class' },
    ASSIGNMENT_NOT_STARTED:
        { statusCode: 500, errorCode: 1503, message: 'Assignment has not yet started' },
    ASSIGNMENT_ENDED:
        { statusCode: 500, errorCode: 1504, message: 'Assignment has ended' },
    ASSIGNMENT_SUBMITTED:
        { statusCode: 500, errorCode: 1505, message: 'Assignment already submitted' },
    CANNOT_SUBMIT:
        { statusCode: 500, errorCode: 1506, message: 'Cannot submit Assignment' },
    INVALID_RESPONSE:
        { statusCode: 500, errorCode: 1507, message: 'Invalid question group, question or question part combination' },
    RESPONSE_NOT_EQUAL_ASSESSMENT:
        { statusCode: 500, errorCode: 1508, message: 'Too many responses provided' },
    INVALID_ASSIGNMENT:
        { statusCode: 500, errorCode: 1509, message: 'Response or Assessment has no questions' },
    ASSIGNMENT_ON_PAPER:
        { statusCode: 500, errorCode: 1510, message: 'This Assignment will be conducted on paper' },
    NOT_ON_TIME:
        { statusCode: 500, errorCode: 1511, message: 'Response not submitted on time' },
    ALL_MANDATORY:
        { statusCode: 500, errorCode: 1512, message: 'All items are mandatory' },
    SUBMISSION_ERROR:
        { statusCode: 500, errorCode: 1513, message: 'Error submitting response' },
    SAVE_ERROR:
        { statusCode: 500, errorCode: 1514, message: 'Error saving response' },
    INVALID_RESPONSE_ON_SUBMIT:
        { statusCode: 500, errorCode: 1515, message: 'Invalid responses when submitting' },
    INVALID_RESPONSE_ON_SAVE:
        { statusCode: 500, errorCode: 1516, message: 'Invalid responses when saving' },
    ASSESSMENT_DATA_ERROR:
        { statusCode: 500, errorCode: 1517, message: 'Error fetching assessment data' },
    USER_DATA_ERROR:
        { statusCode: 500, errorCode: 1518, message: 'Error fetching user data' },
    DATABASE_ERROR:
        { statusCode: 500, errorCode: 1519, message: 'Database Error' },
    ASSIGNMENT_PAUSED:
        { statusCode: 500, errorCode: 1520, message: 'Assignment is paused' },
    QUESTION_PART_DATA_ERROR:
        { statusCode: 500, errorCode: 1521, message: 'Error fetching question parts' },
    ERROR_STARTING_ASSIGNMENT:
        { statusCode: 500, errorCode: 1522, message: 'Error starting student assignment' },
    INVALID_USER_ID:
        { statusCode: 500, errorCode: 1523, message: 'Invalid user ids' },
    INVALID_GRADING:
        { statusCode: 500, errorCode: 1524, message: 'Invalid student assignment grading' },
    RUBRIC_PART_DATA_ERROR:
        { statusCode: 500, errorCode: 1525, message: 'Error fetching rubric parts' },
    CANNOT_OVERRIDE:
        { statusCode: 500, errorCode: 1526, message: 'Cannot override manually scored question parts' },
    INVALID_AUTOSCORE:
        { statusCode: 500, errorCode: 1527, message: 'Rubrics provided for auto score type' },
    POINTS_EXCEED:
        { statusCode: 500, errorCode: 1528, message: 'Cannot assign higher points than limit' },
    CANNOT_CHANGE_AUTOSCORE_VALUE:
        { statusCode: 500, errorCode: 1529, message: 'Cannot change auto score value, only teachers allowed' },
    GRADING_ERROR:
        { statusCode: 500, errorCode: 1530, message: 'Error Grading' },
    INVALID_SCORING:
        { statusCode: 500, errorCode: 1531, message: 'Question part scoring does not match provided scoring method' },
    CANNOT_GRADE:
        { statusCode: 500, errorCode: 1532, message: 'Cannot grade unsubmitted responses' },
    INVALID_RUBRICS:
        { statusCode: 500, errorCode: 1533, message: 'Invalid rubric part id provided' },
    ERROR_SAVING_TIME:
        { statusCode: 500, errorCode: 1534, message: 'Error saving time spent' },
    ONLY_TEACHER_OVERRIDE:
        { statusCode: 500, errorCode: 1535, message: 'Only teacher can override auto scored response' },
    ONLY_RUBRIC:
        { statusCode: 500, errorCode: 1536, message: 'This question can be graded using only rubrics' },
    TEACHER_SETTINGS_ERROR:
        { statusCode: 500, errorCode: 1537, message: 'Error getting teacher assignment settings' },
    SCORE_GENERATION_ERROR:
        { statusCode: 500, errorCode: 1537, message: 'Error generating student score' },
    INVALID_ITEM_DETAILS:
        { statusCode: 500, errorCode: 1539, message: 'Item does not belong to assignment' },
};
