import * as Joi from '@hapi/joi';

const isValidInteger = (value) => {
    return isNaN(parseInt(value, 10)) ? false : true;
};

const checkValidGUID = (input: any): boolean => {
    const uuidValidationSchema = Joi.string().guid();
    const { error } = uuidValidationSchema.validate(input);
    return error ? false : true;
};

const isValidJSONString = (value) => {
    try {
        return (JSON.parse(value) && !!value);
    } catch (e) {
        return false;
    }
};

const isValidTempImageKey = (key) => {
    // uuid4 regex is taken from the source code of node library 'validator':
    // https://github.com/chriso/validator.js/blob/master/src/lib/isUUID.js
    const uuid4 = '[0-9A-F]{8}-[0-9A-F]{4}-[0-9A-F]{4}-[89AB][0-9A-F]{3}-[0-9A-F]{12}';
    const extension = '(png|jpg|jpeg|gif)';
    const imageKeyRegex = new RegExp(`^(images)\/${uuid4}\/${uuid4}.${extension}$`, 'i');

    let isValid = true;
    if (!imageKeyRegex.test(key)) {
        isValid = false;
    }
    return isValid;
};

const isNullOrUndefined = (inputData): boolean => (
    inputData?.length === 0
    || inputData === -1
    || inputData === ''
    || typeof inputData === 'undefined'
    || inputData === null
);

const isNotArrayData = (data): boolean => {
    return (!data || data.length === 0) ? true : false;
};

const checkForValidId = (inputId: any): boolean => (
    !Number.isNaN(inputId) && typeof inputId !== 'undefined' && typeof inputId === 'number'
);

const checkForValidBooleanValue = (inputId: any): boolean => (
    typeof inputId !== 'undefined' && typeof inputId === 'boolean'
);

const checkValidUUID4 = (input: any): boolean => {
    const uuidValidationSchema = Joi.string().uuid({
        version: [
            'uuidv4',
        ],
    });
    const { error } = uuidValidationSchema.validate(input);
    return error ? false : true;
};

export {
    isValidInteger,
    checkValidGUID,
    isValidJSONString,
    isValidTempImageKey,
    isNullOrUndefined,
    isNotArrayData,
    checkForValidId,
    checkForValidBooleanValue,
    checkValidUUID4,
};
