import { decycle } from '../JsonHelper';

describe('JsonHelper', () => {
    describe('decycle with string', () => {
        let response;
        beforeEach(() => {
            const args = {};
            const level = 'info';
            const message = 'test message';
            const ts = '2022-01-01';
            response = decycle(`${ts} [${level}]: ${message} ${Object.keys(args).length ? JSON.stringify(args, null, 2) : ''}`);
        });
        it('should return correct response', () => {
            expect(response).toBe('2022-01-01 [info]: test message ');
        });
    });

    describe('decycle with object', () => {
        let response;
        beforeEach(() => {
            const args = {};
            const level = 'info';
            const message = 'test message';
            const ts = '2022-01-01';
            response = decycle({ level, message, ts, args });
        });
        it('should return correct response', () => {
            expect(response).toHaveProperty('args', {});
            expect(response).toHaveProperty('level', 'info');
            expect(response).toHaveProperty('message', 'test message');
            expect(response).toHaveProperty('ts', '2022-01-01');
        });
    });

    describe('decycle with array', () => {
        let response;
        const array = [{ name: 'Jhon Doe', skills: { frontend: ['react', 'angular'], backend: ['node', 'php'] } }];
        beforeEach(() => {
            response = decycle(array);
        });
        it('should return correct response', () => {
            expect(response).toMatchObject(array);
        });
    });
});
