const loggers = {
    error: jest.fn(),
    info: jest.fn(),
    add: jest.fn(),
};

// trying to mock createLogger to return a specific logger instance
jest.mock('winston', () => ({
    createLogger: jest.fn().mockReturnValue(loggers),
    format: {
        colorize: jest.fn(),
        combine: jest.fn(),
        json: jest.fn(),
        timestamp: jest.fn(),
        printf: jest.fn(),
    },
    transports: {
        Console: jest.fn(),
        File: jest.fn(),
    },
    defaultMeta: { service: 'assessment-service' },
    exitOnError: false,
}));

import winston from 'winston';
import logger from '../logger';

const mockCreateLogger = jest.spyOn(winston, 'createLogger');
const args = { methodName: 'logDataForLogError', status: 500, message: 'dummy message' };

it('test .error()', async () => {
    await logger.error(args);
    expect(mockCreateLogger).toHaveBeenCalled();
    expect(loggers.error).toHaveBeenCalledWith(args);
});

it('test .info()', async () => {
    await logger.info(args);
    expect(mockCreateLogger).toHaveBeenCalled();
    expect(loggers.info).toHaveBeenCalledWith(args);
});

jest.restoreAllMocks();
