import { checkForValidId, checkForValidBooleanValue, checkValidUUID4 } from '../Validators';

describe('checkForValidId', () => {
    describe('when invalid values', () => {

        const invalidIds = ['00000000-0000-5000-A000-000000000001', true, null, 'mock'];

        it.each(invalidIds)('%s - should return false', (value) => {
            const result = checkForValidId(value);
            expect(result).toEqual(false);
        });
    });

    it('should return true for valid values', () => {
        const validId = 1;
        const result = checkForValidId(validId);
        expect(result).toEqual(true);
    });
});

describe('checkForValidBooleanValue', () => {
    describe('when invalid values', () => {

        const invalidValues = ['00000000-0000-5000-A000-000000000001', 23.4, null, 'mock'];

        it.each(invalidValues)('%s - should return false', (value) => {
            const result = checkForValidBooleanValue(value);
            expect(result).toEqual(false);
        });
    });

    it('should return true for valid values', () => {
        const validValue = true;
        const result = checkForValidBooleanValue(validValue);
        expect(result).toEqual(true);
    });
});

describe('checkValidUUID4', () => {

    describe('when invalid values', () => {

        const invalidUUIDs = ['00000000-0000-5000-A000-000000000001', 1, true, null, 'mock'];

        it.each(invalidUUIDs)('%s - should return false', (value) => {
            const result = checkValidUUID4(value);
            expect(result).toEqual(false);
        });
    });

    it('should return true for valid values', () => {
        const validUUID = '00000000-0000-4000-A000-000000000001';
        const result = checkValidUUID4(validUUID);
        expect(result).toEqual(true);
    });
});
