import getEnv from '../getEnv';

describe('getEnv', () => {
    beforeEach(() => {
        delete process.env.NODE_ENV;
    });

    afterEach(() => {
        delete process.env.NODE_ENV;
    });

    it('should return true when NODE_ENV set to "True"', () => {
        process.env.NODE_ENV = 'True';
        expect(getEnv('NODE_ENV', '')).toEqual(true);
    });

    it('should return true when NODE_ENV set to "true"', () => {
        process.env.NODE_ENV = 'true';
        expect(getEnv('NODE_ENV', '')).toEqual(true);
    });

    it('should return false when NODE_ENV set to "False"', () => {
        process.env.NODE_ENV = 'False';
        expect(getEnv('NODE_ENV', '')).toEqual(false);
    });

    it('should return false when NODE_ENV set to "false"', () => {
        process.env.NODE_ENV = 'false';
        expect(getEnv('NODE_ENV', '')).toEqual(false);
    });

    it('should return null when NODE_ENV set to "null"', () => {
        process.env.NODE_ENV = 'null';
        expect(getEnv('NODE_ENV', '')).toEqual(null);
    });

    it('should return value when NODE_ENV does not matches', () => {
        process.env.NODE_ENV = 'dummy_value';
        expect(getEnv('NODE_ENV', '')).toEqual('dummy_value');
    });

    it('should return default value when default value specified', () => {
        expect(getEnv('NODE_ENV', 'TEST')).toEqual('TEST');
    });

});
