import dotenv from 'dotenv';
import {
  getTypeormCacheOptions,
} from '../typeormCache';

describe('typeormCache', () => {
    beforeAll(() => {
        dotenv.config();
    });
    describe('getTypeormCacheOptions', () => {
        const OLD_ENV = process.env;
        let response;
        describe('typeorm cache is false', () => {
            beforeEach(() => {
                jest.resetModules();
                process.env = { ...OLD_ENV, PLAYER__TYPEORM_CACHE_ENABLED: 'false' };
                response = getTypeormCacheOptions();
            });
            afterEach(() => {
                process.env = OLD_ENV;
            });
            it('should retrun false', () => {
                expect(response).toBe(false);
            });
        });
        describe('typeorm cache is true and type is redis', () => {
            let response;
            beforeEach(() => {
                jest.resetModules();
                process.env = {
                    ...OLD_ENV,
                    PLAYER__TYPEORM_CACHE_ENABLED: 'true',
                    PLAYER__TYPEORM_CACHE_TYPE: 'redis',
                };
                response = getTypeormCacheOptions();
            });
            afterEach(() => {
                process.env = OLD_ENV;
            });
            it('should retrun valid response', () => {
                expect(response).toHaveProperty('duration');
                expect(response).toHaveProperty('options');
                expect(response).toHaveProperty('type', 'redis');
            });
        });
        describe('typeorm cache is true and type database', () => {
            let response;
            beforeEach(() => {
                jest.resetModules();
                process.env = {
                    ...OLD_ENV,
                    PLAYER__TYPEORM_CACHE_ENABLED: 'true',
                    PLAYER__TYPEORM_CACHE_TYPE: 'database',
                };
                response = getTypeormCacheOptions();
            });
            afterEach(() => {
                process.env = OLD_ENV;
            });
            it('should retrun valid response', () => {
                expect(response).toHaveProperty('duration');
                expect(response).toHaveProperty('tableName');
                expect(response).toHaveProperty('type', 'database');
            });
        });
        describe('if enable redis password is true', () => {
            let response;
            beforeEach(() => {
                jest.resetModules();
                process.env = {
                    ...OLD_ENV,
                    PLAYER__TYPEORM_CACHE_ENABLED: 'true',
                    PLAYER__TYPEORM_CACHE_TYPE: 'redis',
                    REDIS__ENABLE_PASSWORD: 'true',
                    REDIS__PASSWORD: 'password',
                };
                response = getTypeormCacheOptions();
            });
            afterEach(() => {
                process.env = OLD_ENV;
            });
            it('should return valid response', () => {
                expect(response).toHaveProperty('duration');
                expect(response).toHaveProperty('options');
                expect(response).toHaveProperty('type', 'redis');
                const { options } = response;
                expect(options).toHaveProperty('password', 'password');
            });
        });
        describe('if enable redis ssl is true', () => {
            let response;
            beforeEach(() => {
                jest.resetModules();
                process.env = {
                    ...OLD_ENV,
                    PLAYER__TYPEORM_CACHE_ENABLED: 'true',
                    PLAYER__TYPEORM_CACHE_TYPE: 'redis',
                    REDIS__ENABLE_SSL: 'true',
                };
                response = getTypeormCacheOptions();
            });
            afterEach(() => {
                process.env = OLD_ENV;
            });
            it('should return valid response', () => {
                expect(response).toHaveProperty('duration');
                expect(response).toHaveProperty('options');
                expect(response).toHaveProperty('type', 'redis');
                const { options } = response;
                expect(options).toHaveProperty('tls');
            });
        });
    });

});
