import path from 'path';
import { createLogger, format, transports } from 'winston';
import { decycle } from './JsonHelper';

const options = {
    logFile: {
        filename: path.join(__dirname, '../../log/combined.log'),
        handleExceptions: true,
        json: true,
        maxsize: 5242880,
        maxFiles: 5,
    },
};

const logger = createLogger({
    level: 'info',
    format: format.combine(
        format.colorize(),
        format.json(),
        format.timestamp(),
        format.printf((info) => {
            try {
                const {
                    timestamp, level, message, ...args
                } = info;

                const ts = timestamp.slice(0, 19).replace('T', ' ');
                const decycledArgs = decycle(args);
                return `${ts} [${level}]: ${message} ${Object.keys(decycledArgs).length ? JSON.stringify(decycledArgs, null, 2) : ''}`;
            } catch (error) {
                return error.message;
            }
        }),
    ),
    defaultMeta: { service: 'itemengine-player-service' },
    transports: [
        new transports.File(options.logFile),
    ],
    exceptionHandlers: [new transports.File(options.logFile)],
});

if (process.env.NODE_ENV !== 'production') {
    logger.add(new transports.Console({
        format: format.combine(
            format.timestamp(),
            format.colorize(),
            format.json(),
            format.printf((info) => {
                const {
                    timestamp, level, message, ...args
                } = info;
                const ts = timestamp.slice(0, 19).replace('T', ' ');

                return `${ts} [${level}]: ${message} ${Object.keys(args).length ? JSON.stringify(args, null, 0) : ''}`;
            }),
        ),
    }));
}

process.on('unhandledRejection', (err: Error) => {
    logger.error({
        message: err.message,
        error: err,
    });
});

export default logger;
